==> magic3_1.8.0_b9_src.tar.gz: magic3/widgets/reg_user/include/container/reg_userRegistWidgetContainer.php <==
<?php
/**
 * index.php用コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: reg_userRegistWidgetContainer.php 2030 2009-07-02 02:59:00Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
require_once($gEnvManager->getIncludePath() . '/common/userInfo.php');		// ユーザ情報クラス
require_once($gEnvManager->getCurrentWidgetDbPath() .	'/reg_userDb.php');

class reg_userRegistWidgetContainer extends BaseWidgetContainer
{
	private $db;	// DB接続オブジェクト
	private $sysDb;		// システムDBオブジェクト
	const DEFAULT_CAN_REGIST = 1;			// ユーザ登録を使用するかどうか
	const REGIST_USER_AUTO_FORM = 'regist_user_auto';		// パスワード送信用フォーム(自動登録)
	const REGIST_USER_AUTH_FORM = 'regist_user_auth';		// パスワード送信用フォーム(管理者認証)
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
		
		// DB接続オブジェクト作成
		$this->db = new reg_userDb();
		$this->sysDb = $this->gInstance->getSytemDbObject();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{
		return 'index.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		$paramObj = $this->getWidgetParamObj();
		if (!empty($paramObj)){
			$this->authType	= $paramObj->authType;			// 承認タイプ
		}
		if (empty($this->authType)){
			$this->tmpl->addVar("_widget", "send_button_label", '未設定');// 送信ボタンラベル
			return;			// 承認タイプが設定されていないときは終了
		}
				
		$act = $request->trimValueOf('act');

		// デフォルト値取得
		$canRegist = self::DEFAULT_CAN_REGIST;			// ユーザ登録を使用するかどうか
		$inputEnabled = true;			// 入力の許可状態
		
		// 入力値取得
		$name = $request->trimValueOf('item_name');			// 名前
		$email = $request->trimValueOf('item_email');	// Email
		$email2 = $request->trimValueOf('item_email2');	// Email確認用
	
		if ($act == 'regist'){			// ユーザ登録
			$this->checkInput($name, '名前');
			$this->checkMailAddress($email, 'Eメール');
			$this->checkMailAddress($email2, 'Eメール(確認)');
			if ($this->getMsgCount() == 0){			// メールアドレスのチェック
				if ($email != $email2){
					$this->setAppErrorMsg('Eメールアドレスに誤りがあります');
				} else if ($this->sysDb->isExistsAccount($email)){// メールアドレスがログインIDとして既に登録されているかチェック
					$this->setAppErrorMsg('このEメールアドレスは既に登録されています');
				}
			}
		
			// エラーなしの場合はメール送信
			if ($this->getMsgCount() == 0){
				// パスワード作成
				$password = $this->makePassword();

				// ログインユーザを作成
				$ret = $this->db->addUser($name, $email, $password, $this->gEnv->getCurrentWidgetId(), $loginUserId);		// 新規ログインユーザIDを取得
				if ($ret){
					// メールフォームタイプ
					if ($this->authType == 'auto'){			// 自動認証
						$formType = self::REGIST_USER_AUTO_FORM;		// パスワード送信用フォーム(自動登録)
						$message = '登録完了しました。指定のメールアドレス宛てにパスワードが送信されます。<br />再度ログインしてください。';
					} else {
						$formType = self::REGIST_USER_AUTH_FORM;		// パスワード送信用フォーム(管理者認証)
						$message = '登録完了しました。指定のメールアドレス宛てにパスワードが送信されます。<br />管理者からの承認後、ログイン可能になります。';
					}
					//$fromAddress = $this->mainDb->getConfig(self::AUTO_EMAIL_SENDER);	// 自動送信送信元
					$fromAddress = '';			// 管理者宛メールアドレス
					if (empty($fromAddress)) $fromAddress = $this->gEnv->getSiteEmail();// 送信元が取得できないときは、システムのデフォルトメールアドレスを使用
					$toAddress = $email;			// eメール(ログインアカウント)
					$ccAddress = $fromAddress;		// CCメール
					$url = $this->gEnv->createCurrentPageUrl() . '&task=login&act=user_maillogin&account=' . urlencode($email) . '&pwd=' . urlencode($password);		// ログイン用URL
					$mailParam = array();
					$mailParam['PASSWORD'] = $password;
					$mailParam['URL']		= $url;		// ログイン用URL
					$ret = $this->gMail->sendFormMail(1, $this->gEnv->getCurrentWidgetId(), $toAddress, $fromAddress, '', '', $formType, $mailParam, $ccAddress);// 自動送信
					$this->setGuidanceMsg($message);
		
					// 項目を入力不可に設定
					$inputEnabled = false;			// 入力の許可状態

					$this->tmpl->addVar("_widget", "send_button_disabled", 'disabled');// 送信ボタン
				}
			}
			
			$this->tmpl->addVar("_widget", "send_button_label", '登録する');// 送信ボタンラベル
		} else {
			// メール送信不可の場合はボタンを使用不可にする
			if ($canRegist){
				$this->tmpl->addVar("_widget", "send_button_label", '登録する');// 送信ボタンラベル
			} else {
				$this->tmpl->addVar("_widget", "send_button_label", '登録停止中');// 送信ボタンラベル
				$this->tmpl->addVar("_widget", "send_button_disabled", 'disabled');// 送信ボタン
			}
		}
	
		// 入力値を戻す
		$this->tmpl->addVar("_widget", "name", $name);
		$this->tmpl->addVar("_widget", "email", $email);
		$this->tmpl->addVar("_widget", "email2", $email2);
		
		// ボタンの状態を設定
		if (!$inputEnabled){			// 入力の許可状態
			$this->tmpl->addVar('_widget', 'name_disabled', 'disabled');
			$this->tmpl->addVar('_widget', 'email_disabled', 'disabled');
			$this->tmpl->addVar('_widget', 'email2_disabled', 'disabled');
		}
	}
}
?>

==> magic3_1.8.5_src.tar.gz: magic3/widgets/reg_user/include/container/reg_userRegistWidgetContainer.php <==
<?php
/**
 * index.php用コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: reg_userRegistWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
require_once($gEnvManager->getIncludePath() . '/common/userInfo.php');		// ユーザ情報クラス
require_once($gEnvManager->getCurrentWidgetDbPath() .	'/reg_userDb.php');

class reg_userRegistWidgetContainer extends BaseWidgetContainer
{
	private $db;	// DB接続オブジェクト
	private $sysDb;		// システムDBオブジェクト
	const DEFAULT_CAN_REGIST = 1;			// ユーザ登録を使用するかどうか
	const REGIST_USER_AUTO_FORM = 'regist_user_auto';		// パスワード送信用フォーム(自動登録)
	const REGIST_USER_AUTH_FORM = 'regist_user_auth';		// パスワード送信用フォーム(管理者認証)
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
		
		// DB接続オブジェクト作成
		$this->db = new reg_userDb();
		$this->sysDb = $this->gInstance->getSytemDbObject();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{
		return 'index.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		$paramObj = $this->getWidgetParamObj();
		if (!empty($paramObj)){
			$this->authType	= $paramObj->authType;			// 承認タイプ
		}
		if (empty($this->authType)){
			$this->tmpl->addVar("_widget", "send_button_label", '未設定');// 送信ボタンラベル
			return;			// 承認タイプが設定されていないときは終了
		}
				
		$act = $request->trimValueOf('act');

		// デフォルト値取得
		$canRegist = self::DEFAULT_CAN_REGIST;			// ユーザ登録を使用するかどうか
		$inputEnabled = true;			// 入力の許可状態
		
		// 入力値取得
		$name = $request->trimValueOf('item_name');			// 名前
		$email = $request->trimValueOf('item_email');	// Email
		$email2 = $request->trimValueOf('item_email2');	// Email確認用
	
		if ($act == 'regist'){			// ユーザ登録
			$this->checkInput($name, '名前');
			$this->checkMailAddress($email, 'Eメール');
			$this->checkMailAddress($email2, 'Eメール(確認)');
			if ($this->getMsgCount() == 0){			// メールアドレスのチェック
				if ($email != $email2){
					$this->setAppErrorMsg('Eメールアドレスに誤りがあります');
				} else if ($this->sysDb->isExistsAccount($email)){// メールアドレスがログインIDとして既に登録されているかチェック
					$this->setAppErrorMsg('このEメールアドレスは既に登録されています');
				}
			}
		
			// エラーなしの場合はメール送信
			if ($this->getMsgCount() == 0){
				// パスワード作成
				$password = $this->makePassword();

				// ログインユーザを作成
				$ret = $this->db->addUser($name, $email, $password, $this->gEnv->getCurrentWidgetId(), $loginUserId);		// 新規ログインユーザIDを取得
				if ($ret){
					// メールフォームタイプ
					if ($this->authType == 'auto'){			// 自動認証
						$formType = self::REGIST_USER_AUTO_FORM;		// パスワード送信用フォーム(自動登録)
						$message = '登録完了しました。指定のメールアドレス宛てにパスワードが送信されます。<br />再度ログインしてください。';
					} else {
						$formType = self::REGIST_USER_AUTH_FORM;		// パスワード送信用フォーム(管理者認証)
						$message = '登録完了しました。指定のメールアドレス宛てにパスワードが送信されます。<br />管理者からの承認後、ログイン可能になります。';
					}
					//$fromAddress = $this->mainDb->getConfig(self::AUTO_EMAIL_SENDER);	// 自動送信送信元
					$fromAddress = '';			// 管理者宛メールアドレス
					if (empty($fromAddress)) $fromAddress = $this->gEnv->getSiteEmail();// 送信元が取得できないときは、システムのデフォルトメールアドレスを使用
					$toAddress = $email;			// eメール(ログインアカウント)
					$ccAddress = $fromAddress;		// CCメール
					$url = $this->gEnv->createCurrentPageUrl() . '&task=login&act=user_maillogin&account=' . urlencode($email) . '&pwd=' . urlencode($password);		// ログイン用URL
					$mailParam = array();
					$mailParam['PASSWORD'] = $password;
					$mailParam['URL']		= $this->getUrl($url, true);		// ログイン用URL
					$ret = $this->gMail->sendFormMail(1, $this->gEnv->getCurrentWidgetId(), $toAddress, $fromAddress, '', '', $formType, $mailParam, $ccAddress);// 自動送信
					$this->setGuidanceMsg($message);
		
					// 項目を入力不可に設定
					$inputEnabled = false;			// 入力の許可状態

					$this->tmpl->addVar("_widget", "send_button_disabled", 'disabled');// 送信ボタン
				}
			}
			
			$this->tmpl->addVar("_widget", "send_button_label", '登録する');// 送信ボタンラベル
		} else {
			// メール送信不可の場合はボタンを使用不可にする
			if ($canRegist){
				$this->tmpl->addVar("_widget", "send_button_label", '登録する');// 送信ボタンラベル
			} else {
				$this->tmpl->addVar("_widget", "send_button_label", '登録停止中');// 送信ボタンラベル
				$this->tmpl->addVar("_widget", "send_button_disabled", 'disabled');// 送信ボタン
			}
		}
	
		// 入力値を戻す
		$this->tmpl->addVar("_widget", "name", $name);
		$this->tmpl->addVar("_widget", "email", $email);
		$this->tmpl->addVar("_widget", "email2", $email2);
		
		// ボタンの状態を設定
		if (!$inputEnabled){			// 入力の許可状態
			$this->tmpl->addVar('_widget', 'name_disabled', 'disabled');
			$this->tmpl->addVar('_widget', 'email_disabled', 'disabled');
			$this->tmpl->addVar('_widget', 'email2_disabled', 'disabled');
		}
	}
}
?>
